==> albert_0.27.0.orig.tar.gz: albert-0.27.0/plugins/snippets/i18n/snippets_de.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de_DE">
<context>
    <name>ConfigWidget</name>
    <message>
        <source>Snippets are plain text files whose content can be copied to the clipboard or directly inserted into the focused window.</source>
        <translation>Textschnipsel sind Klartextdateien, deren Inhalt in die Zwischenablage kopiert oder direkt in das fokussierte Fenster eingefügt werden kann.</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Hinzufügen</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Entfernen</translation>
    </message>
    <message>
        <source>Open snippet dir</source>
        <translation>Schnipselverzeichnis öffnen</translation>
    </message>
</context>
<context>
    <name>Plugin</name>
    <message>
        <source>&lt;filter&gt;|+</source>
        <translation>&lt;Filter&gt;|+</translation>
    </message>
    <message>
        <source>Create new snippet</source>
        <translation>Neues Schnipsel erstellen</translation>
    </message>
    <message>
        <source>Create snippet file and open it in default editor.</source>
        <translation>Neue Schnipseldatei erstellen und in Standardeditor öffnen.</translation>
    </message>
    <message>
        <source>Create</source>
        <translation>Erstellen</translation>
    </message>
    <message>
        <source>Snippet name:</source>
        <translation>Schnipselname:</translation>
    </message>
    <message>
        <source>The snippet name must not be empty.</source>
        <translation>Der Schnipselname darf nicht leer sein.</translation>
    </message>
    <message>
        <source>There is already a snippet called &apos;%1&apos;.</source>
        <translation>Es gibt bereits ein Schnipsel mit dem Namen &apos;%1&apos;.</translation>
    </message>
    <message>
        <source>Failed creating the snippet file &apos;%1&apos;.</source>
        <translation>Erstellen der Schnipseldatei &apos;%1&apos; fehlgeschlagen.</translation>
    </message>
    <message>
        <source>Move snippet &apos;%1&apos; to trash?</source>
        <translation>Snippet &apos;%1&apos; in den Papierkorb verschieben?</translation>
    </message>
    <message>
        <source>Failed to move snippet file to trash.</source>
        <translation>Schnipseldatei konnte nicht in den Papierkorb verschoben werden.</translation>
    </message>
</context>
<context>
    <name>SnippetItem</name>
    <message>
        <source>Text snippet</source>
        <translation>Textschnipsel</translation>
    </message>
    <message>
        <source>Copy and paste</source>
        <translation>Kopieren und einfügen</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Kopieren</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>Bearbeiten</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Entfernen</translation>
    </message>
</context>
</TS>

==> albert_0.28.0.orig.tar.gz: albert-0.28.0/plugins/snippets/i18n/snippets_de.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de_DE">
<context>
    <name>ConfigWidget</name>
    <message>
        <source>Snippets are plain text files whose content can be copied to the clipboard or directly inserted into the focused window.</source>
        <translation>Textschnipsel sind Klartextdateien, deren Inhalt in die Zwischenablage kopiert oder direkt in das fokussierte Fenster eingefügt werden kann.</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Hinzufügen</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Entfernen</translation>
    </message>
    <message>
        <source>Open snippet dir</source>
        <translation>Schnipselverzeichnis öffnen</translation>
    </message>
</context>
<context>
    <name>FilenameDialog</name>
    <message>
        <source>Snippet name:</source>
        <translation>Schnipselname:</translation>
    </message>
    <message>
        <source>The snippet name must not be empty.</source>
        <translation>Der Schnipselname darf nicht leer sein.</translation>
    </message>
    <message>
        <source>There is already a snippet called &apos;%1&apos;.</source>
        <translation>Es gibt bereits einen Schnipsel mit dem Namen &apos;%1&apos;.</translation>
    </message>
</context>
<context>
    <name>Plugin</name>
    <message>
        <source>&lt;filter&gt;|+</source>
        <translation>&lt;Filter&gt;|+</translation>
    </message>
    <message>
        <source>Create new snippet</source>
        <translation>Neuen Schnipsel erstellen</translation>
    </message>
    <message>
        <source>Create snippet file and open it in default editor.</source>
        <translation>Neue Schnipseldatei erstellen und in Standardeditor öffnen.</translation>
    </message>
    <message>
        <source>Create</source>
        <translation>Erstellen</translation>
    </message>
    <message>
        <source>Failed creating the snippet file &apos;%1&apos;.</source>
        <translation>Erstellen der Schnipseldatei &apos;%1&apos; fehlgeschlagen.</translation>
    </message>
    <message>
        <source>Move snippet &apos;%1&apos; to trash?</source>
        <translation>Schnipsel &apos;%1&apos; in den Papierkorb verschieben?</translation>
    </message>
    <message>
        <source>Failed to move snippet file to trash.</source>
        <translation>Schnipseldatei konnte nicht in den Papierkorb verschoben werden.</translation>
    </message>
    <message>
        <source>Text snippet</source>
        <translation>Textschnipsel</translation>
    </message>
    <message>
        <source>Copy and paste</source>
        <translation>Kopieren und einfügen</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Kopieren</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>Bearbeiten</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Entfernen</translation>
    </message>
    <message>
        <source>[snippet text]</source>
        <translation>[Schnipseltext]</translation>
    </message>
</context>
</TS>
